import {
  Body,
  Controller,
  Delete,
  Get,
  Param,
  Post,
  Put,
  UsePipes,
  ValidationPipe,
} from '@nestjs/common';
import { DeleteResult } from 'typeorm';
import { SongService } from './song.service';
import { Song } from './song.entity';
import { CreateSongDto } from './dto/create-song.dto';
import { UpdateSongDto } from './dto/update-song.dto';
import {UUID} from "crypto";

@Controller('song')
export class SongController {
  constructor(private readonly songService: SongService) {}

  @Get()
  findAll(): Promise<Song[] | string | null> {
    return this.songService.findAll();
  }

  @Get(':uuid')
  findOneById(@Param('uuid') uuid: UUID): Promise<Song | string | null> {
    return this.songService.findOneById(uuid);
  }

  @Post()
  @UsePipes(new ValidationPipe({ transform: true, whitelist: true }))
  async create(@Body() createSongDto: CreateSongDto): Promise<Song | string | null> {
    return this.songService.create(createSongDto);
  }

  @Put(':uuid')
  @UsePipes(new ValidationPipe({ transform: true, whitelist: true }))
  async update(
    @Param('uuid') uuid: UUID,
    @Body() updateSongDto: UpdateSongDto,
  ): Promise<Song | string | null> {
    console.log(updateSongDto);
    return this.songService.update(uuid, updateSongDto);
  }

  @Delete(':uuid')
  async remove(@Param('uuid') uuid: UUID): Promise<DeleteResult | string | null> {
    return this.songService.remove(uuid);
  }
}
