import {Entity, Column, ManyToOne, PrimaryGeneratedColumn, Generated} from 'typeorm';
import { IsNotEmpty, IsNumber, IsString } from 'class-validator';
import { Album } from '../album/album.entity';
import { UUID } from 'crypto';

@Entity('song')
export class Song {
  @PrimaryGeneratedColumn()
  @Generated("uuid")
  uuid: UUID;

  @Column({ unique: true })
  @IsString()
  @IsNotEmpty()
  title: string;

  @Column()
  @IsNumber()
  duration: number;

  @Column()
  @IsNumber()
  trackNumber: number;

  @ManyToOne(() => Album, (album) => album.songs, { onDelete: 'CASCADE' })
  album: Album;
}
