import Form from 'next/form';
import Button from "react-bootstrap/Button";
import React, {FormEvent, useState} from "react";
import {createAlbum, getAlbums, revalidateAlbums, updateAlbum} from "@/app/actions";

export default function AlbumForm() {
    const [formData, setFormData] = useState({
        id: '',
        title: '',
        artist: '',
        genre: '',
    });

    const handleChange = (e: React.ChangeEvent<HTMLInputElement>) => {
        const { name, value } = e.target;
        setFormData((prevData) => ({
            ...prevData,
            [name]: value,
        }));
    };

    const handleSubmit = async (event: React<FormEvent>) => {
        event.preventDefault();
        try {
            if (formData.id == "") {
                await createAlbum(formData)
                    .then((response) => {
                        if (response.messages) {
                            // handleSnackbar(`Failed to create Album with ID ${formData.id}: ${JSON.stringify(response)}`, false);
                        } else {
                            // handleSnackbar(`Successfully created Album with ID ${formData.id}`, true);
                        }
                    })
                    .catch(error => {
                        // handleSnackbar(`Failed to create Album with ID ${formData.id}: ${JSON.stringify(error)}`, false);
                    });
            } else {
                await updateAlbum(formData)
                    .then(() => {
                        // handleSnackbar(`Successfully updated Album with ID ${formData.id}`, true);
                    })
                    .catch(error => {
                        // handleSnackbar(`Failed to update Album with ID ${formData.id}: ${JSON.stringify(error)}`, false);
                    });
            }
            revalidateAlbums();
            const data = await getAlbums();
            // setAlbums(data);
        } catch (error) {
            // handleSnackbar(`Error creating Album: ${JSON.stringify(error)}`, false);
        }
    }

    return (
        <Form onSubmit={handleSubmit}>
            <input name="id" id="album-id" value={formData.id} type="hidden" />
            <div className="row">
                <div className="six columns">
                    <label htmlFor="album-title">Album Title</label>
                    <input type="text" name="title" id="album-title" onChange={handleChange} defaultValue={formData.title} />
                </div>
                <div className="six columns">
                    <label htmlFor="album-artist">Artist</label>
                    <input type="text" name="artist" id="album-artist" onChange={handleChange} defaultValue={formData.artist} />
                </div>
            </div>
            <div className="row">
                <div className="six columns">
                    <label htmlFor="album-genre">Genre</label>
                    <input type="text" name="genre" id="album-genre" onChange={handleChange} defaultValue={formData.genre} />
                </div>
            </div>
            <Button variant="primary" type="submit">Submit</Button>
        </Form>
    )
}